@@ -15,11 +15,13 @@ use List::Util qw/shuffle/;
 # use IPC::Cmd qw/can_run/;
 
 use Moose;
+use namespace::autoclean;
+
 extends 'HPC::Runner';
 extends 'HPC::Runner::Slurm';
 with 'MooseX::SimpleConfig';
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # For pretty man pages!
 $ENV{TERM}='xterm-256color';
@@ -52,8 +54,11 @@ has 'queue' => (
     is => 'rw',
     isa => 'Str',
     required => 1,
-    default => 'adserial',
-    documentation => q{PBS queue for job submission. Defaults to the s48 queue}
+    #default => 'adserial',
+    default => q(),
+    documentation => q{PBS queue for job submission. Defaults is none, pbs decides.},
+    predicate => 'has_queue',
+    clearer => 'clear_queue',
 );
 
 =head2 walltime
@@ -105,7 +110,9 @@ has '+template_file' => (
 #!/bin/bash
 #
 #PBS -N [% JOBNAME %]
-#PBS -q [% PARTITION %]
+[% IF self.has_queue %]
+#PBS -q [% self.queue %]
+[% END %]
 #PBS -l nodes=1:ppn=[% CPU %]
 [% IF self.has_walltime %]
 #PBS -l walltime=[% self.walltime %]
@@ -257,7 +264,6 @@ sub submit_slurm{
 
 
 __PACKAGE__->meta->make_immutable;
-#use namespace::autoclean;
 1;
 
 __END__
